@@ -13,11 +13,11 @@ App::ZFSCurses::Backend - Perform backend operations.
 
 =head1 VERSION
 
-Version 1.200.
+Version 1.210.
 
 =cut
 
-our $VERSION = '1.200';
+our $VERSION = '1.210';
 
 =head1 METHODS
 
@@ -171,19 +171,19 @@ sub set_zfs_property {
     close $zfs_set_fh;
 }
 
-=head2 destroy_zfs_snapshot
+=head2 destroy_zfs
 
-Destroy a given snapshot recursively.
+Destroy a given object: snapshot, dataset, volume.
 
 =cut
 
-sub destroy_zfs_snapshot {
+sub destroy_zfs {
     my $self = shift;
 
-    @_ == 1 || die qq#Usage: destroy_zfs_snapshot(snapshot)#;
-    my $snapshot = shift;
+    @_ == 1 || die qq#Usage: destroy_zfs(object)#;
+    my $object = shift;
 
-    my @zfs_destroy_args = ( 'zfs', 'destroy', '-r', $snapshot );
+    my @zfs_destroy_args = ( 'zfs', 'destroy', '-r', $object );
 
     open( my $zfs_destroy_fh, '-|', @zfs_destroy_args )
       or die "can't run @zfs_destroy_args $!";
@@ -203,7 +203,7 @@ Patrice Clement <monsieurp at cpan.org>
 
 This software is copyright (c) 2020 by Patrice Clement.
 
-This is free software, licensed under the (three-clause) clause BSD License.
+This is free software, licensed under the (three-clause) BSD License.
 
 See the LICENSE file.
 
