@@ -6,17 +6,17 @@ use warnings;
 
 =head1 NAME
 
-App::ZFSCurses::WidgetFactory - a factory to create widgets.
+App::ZFSCurses::WidgetFactory - Create widgets.
 
 =head1 METHODS
 
 =head1 VERSION
 
-Version 1.200.
+Version 1.210.
 
 =cut
 
-our $VERSION = '1.200';
+our $VERSION = '1.210';
 
 =head2 new
 
@@ -240,7 +240,7 @@ Patrice Clement <monsieurp at cpan.org>
 
 This software is copyright (c) 2020 by Patrice Clement.
 
-This is free software, licensed under the (three-clause) clause BSD License.
+This is free software, licensed under the (three-clause) BSD License.
 
 See the LICENSE file.
 
